
import pytest, os, sys, inspect
from lib389.ds_instance import DSModuleProxy

sys.dont_write_bytecode = True

class MockDS(object):
    """
        DS mock class for testing purposes
    """

    def __init__(self):
        self.dit = {}

    def ldapadd_r(self, input):
        """Simulates adding entry to DS

        The entry can be found in self.dit attribute, which is 
        a dict with structure {'dn of entry' : entry}. Entry is 
        also converted to dict with structure {attr_name : attr_value}
        """
        input = input.strip()
        entry = dict(e.strip().split(': ') for e in input.split('\n'))
        self.dit[entry['dn']] = entry

    def ldapdelete_r(self, dn):
        """
            Simulates deletion of entry from DS
        """
        del self.dit[dn]

@pytest.fixture
def fake_ds_inst_with_repl():
    """
        Fixture returns mock DS object with real repl module attached to it
    """
    ds_inst = MockDS()
    path_to_repl_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))) + "/../../lib389/dsmodules"
    DSModuleProxy.populate_with_proxies(ds_inst, ds_inst, path_to_repl_dir)
    return ds_inst
